# MyForestPlot
[![python](https://img.shields.io/pypi/pyversions/myforestplot)](https://www.python.org/)
[![PyPI](https://img.shields.io/pypi/v/myforestplot.svg)](https://pypi.org/project/myforestplot/)
[![license](https://img.shields.io/pypi/l/myforestplot?color=blue)](https://github.com/toshiakiasakura/myforestplot/blob/main/LICENSE)

Source code repository for the myforestplot package.

Create a forest plot by python more easily and intuitively. 

# Installation
```bash
pip install myforestplot
```

# Usage
See documentation page : https://toshiakiasakura.github.io/myforestplot/


